@@ -1,10 +1,9 @@
 pub mod array;
 pub mod bit_util;
-pub mod builder;
 pub mod error;
 pub mod is_valid;
 pub mod kernels;
 pub mod prelude;
 pub mod trusted_len;
 pub mod utils;
-pub mod vec;
+pub use arrow;
